@@ -10,15 +10,14 @@ import time
 import django
 import simpleui
 from django import template
-
+from django.contrib.admin.templatetags.admin_urls import add_preserved_filters
 from django.core.serializers.json import DjangoJSONEncoder
 from django.db import models
-from django.urls import reverse, is_valid_path
+from django.urls import is_valid_path, reverse
 from django.utils.encoding import force_text
 from django.utils.functional import Promise
 from django.utils.html import format_html
 from django.utils.safestring import mark_safe
-from django.contrib.admin.templatetags.admin_urls import add_preserved_filters
 
 register = template.Library()
 
@@ -257,13 +256,6 @@ def menus(context, _get_config=None):
 
     # 给每个菜单增加一个唯一标识，用于tab页判断
     eid = 1000
-    # for i in data:
-    #     eid += 1
-    #     i['eid'] = eid
-    #     if 'models' in i:
-    #         for k in i.get('models'):
-    #             eid += 1
-    #             k['eid'] = eid
     handler_eid(data, eid)
     menus_string = json.dumps(data, cls=LazyEncoder)
 
@@ -477,7 +469,11 @@ def simple_version():
 def get_model_url(context):
     # reverse()
     opts = context.get("opts")
-    key = "admin:{}_{}_changelist".format(opts.app_label, opts.model_name)
+    request = context.get("request")
+
+    key = "{}:{}_{}_changelist".format(
+        get_current_app(request), opts.app_label, opts.model_name
+    )
     url = reverse(key)
     preserved_filters = dict(parse_qsl(context.get("preserved_filters")))
     if "_changelist_filters" in preserved_filters:
@@ -486,10 +482,26 @@ def get_model_url(context):
     return url
 
 
+def get_current_app(request):
+    app = None
+    if hasattr(request, 'current_app'):
+        app = getattr(request, 'current_app')
+    elif hasattr(request, 'model_admin'):
+        model_admin = getattr(request, 'model_admin')
+        if hasattr(model_admin, 'opts'):
+            opts = getattr(model_admin, 'opts')
+            app = opts.app_config.name
+    return app
+
+
 @register.simple_tag(takes_context=True)
 def get_model_ajax_url(context):
     opts = context.get("opts")
-    key = "admin:{}_{}_ajax".format(opts.app_label, opts.model_name)
+    request = context.get("request")
+
+    key = "{}:{}_{}_changelist".format(
+        get_current_app(request), opts.app_label, opts.model_name
+    )
     try:
         return reverse(key)
     except:
@@ -530,3 +542,12 @@ def get_previous_url(context):
 @register.simple_tag(takes_context=True)
 def get_verbose_name_plural(context):
     return context['cl'].model._meta.verbose_name_plural
+
+
+@register.simple_tag
+def django_version_is_gte_32x():
+    arrays = django.get_version().split(".")
+    version = []
+    for s in arrays:
+        version.append(int(s))
+    return tuple(version) >= (3, 2)
